@@ -7,7 +7,8 @@ import json
 from json.encoder import JSONEncoder
 from feed.actiontypes import ReturnTypes
 from bs4 import BeautifulSoup, Tag
-from feed.settings import kafka_params, routing_params
+from feed.settings import kafka_params, routing_params, nanny_params
+from feed.actiontypes import ActionChainException
 import signal
 
 
@@ -125,7 +126,7 @@ class Action(BrowserSearchParams):
         self.position = position
 
     def getActionHash(self):
-        return hashlib.md5(f'{type(self).__name__}:{self.position}:{self.css}:{self.xpath}:{self.inputString}:{self.text}')
+        return hashlib.md5(f'{type(self).__name__}:{self.position}:{self.css}:{self.xpath}'.encode('utf-8')).hexdigest()
 
     @staticmethod
     def execute(chain, action):
@@ -135,7 +136,7 @@ class Action(BrowserSearchParams):
             logging.debug(f'Action::execute: Action executed succesfully, name=[{chain.name}], position=[{action.position}]')
             return ret
         except ActionChainException as ex:
-            self.publishActionEror(ex)
+            Action.publishActionEror(ex)
             logging.info(f'{type(ex).__name__} thrown whilst processing')
             return False
         except Exception as ex:
@@ -155,8 +156,8 @@ class Action(BrowserSearchParams):
         # TODO For UI-Server
         return [self.__dict__().keys()]
 
-    def publishActionEror(self, actionException):
-        requests.put('http://{host}:{port}/actionsmanager/reportActionError/{name}'.format(name=actionException.chainName, **nanny_params), data=json.dumps(actionException.__dict__()), mimetype='application/json')
+    def publishActionEror(actionException):
+        requests.put('http://{host}:{port}/actionsmanager/reportActionError/{name}'.format(name=actionException.chainName, **nanny_params), json=actionException.__dict__())
 
 
 class CaptureAction(Action):
@@ -222,7 +223,6 @@ class ActionChain:
                 traceback.print_exc()
                 logging.error(f'{type(self).__name__}::__init__(): chainName=[{self.name}], position=[{order}] actionType=[{params.get("actionType")}] is missing {ex.args} default parameter')
 
-
     def recoverHistory(self):
         try:
             req = requests.get('http://{host}:{port}/routingcontroller/getLastPage/{name}'.format(name=self.name, **routing_params))
@@ -387,16 +387,30 @@ class ActionChainRunner:
                 self.cleanUp()
                 logging.info(f'cleaned up resources')
                 break
+            if not self.shouldRun(actionChain):
+                logging.info(f'Skipping {actionChainParams.get("name")}.')
+                # TODO notifications service here
+                continue
             actionChain = self.implementation(driver=self.driver, **actionChainParams)
             logging.info(f'{type(self).__name__}::main(): START:{actionChain.name} implementing action chain {actionChainParams.get("name")}: {json.dumps(actionChainParams, indent=4)}')
             ret = actionChain.execute(self)
             self.onChainEndCallback(actionChain, ret)
             # should the chain be automatically be re ran from where we are?
             # this can be disabled in the implementation of onChainEndCallback
-            while actionChain.repeating and not actionChain.failedChain:
-                actionChain.execute(caller=self, initialise=False)
+            while actionChain.repeating and not actionChain.failedChain and self.shouldRun(actionChain):
+                ret = actionChain.execute(caller=self, initialise=False)
+                self.onChainEndCallback(actionChain, ret)
             logging.info(f'{type(self).__name__}::main(): END:{actionChain.name} ActionChain::execute() has returned')
 
+    def shouldRun(self, actionChain: ActionChain):
+        for actionIndex in range(actionChain.actions):
+            logging.debug(f'Checking if {actionIndex} in {actionChain.name} can be run')
+            errorReq = requests.get('http://{host}:{port}/actionsmanager/findActionErrorReports/{name}/{pos}'.format(**nanny_params, name=actionChain.name, pos=actionIndex))
+            errors = errorReq.json()
+            if len(errors) > 0:
+                logging.info(f'Will not run {actionChain.name}')
+                return False
+
     def cleanUp(self):
         logging.warning(f'ActionChainRunner::cleanUp() No cleanup has been implemented')
 
